# ⚠️ This package is deprecated ⚠️ 

---
Please refer to other packages that are actively maintained:

- [neptune-client](https://github.com/neptune-ai/neptune-client)
- [neptune-fetcher](https://github.com/neptune-ai/neptune-fetcher)

